django-ttag — django-ttag v1.0-alpha-2 documentation

# django-ttag v1.0-alpha-2 documentation

next | index

# django-ttag

This documentation covers the 1.0 release of django-ttag, a template tag constructor library for Django created for the purpose of making writing template tags easier.

The tag syntax is modelled on Django’s friendly syntaxes for models and forms.

To get up and running, consult the installation guide which describes all the necessary steps to install and configure this application.

- Installation
  - Installing django-ttag
  - Configuring your project
- Usage
  - Example
  - Defining arguments
  - Altering context
  - Cleaning arguments
  - Writing a block tag
  - Full Example
- Reference
  - Overview
  - Tag
  - Arguments
  - Argument Types